==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.tools/src/com/openexchange/office/tools/htmldoc/Text.java <==
package com.openexchange.office.tools.htmldoc;

import org.apache.commons.lang.StringEscapeUtils;

public class Text
        extends SubNode
{
    private static final String SPANBEFORE = "<span ";
    private static final String SPANMIDDLE = "style=\"font-family: Arial, Helvetica, sans-serif; font-weight: normal; font-style: normal; text-decoration: none; color: rgb(0, 0, 0); font-size: 11pt; vertical-align: baseline; line-height: 20px; background-color: transparent;\">";
    private static final String SPANEND    = "</span>";

    // ////////////////////////////////////////////////////

    private final String        text;
    private boolean style = true;

    public Text(
            String text, int position)
    {
        super(position, text.length());
        this.text = text;
    }

    public String getText()
    {
        return text;
    }

    @Override
    public boolean appendContent(
        StringBuilder document)
        throws Exception
    {
        document.append(SPANBEFORE);
        GenDocHelper.appendAttributes(getAttribute(), document);
        if (isStyle()) {
            document.append(SPANMIDDLE);            
        } else {
            document.append(">");
        }

        document.append(StringEscapeUtils.escapeHtml(text));
        document.append(SPANEND);
        return true;
    }

    @Override
    public String toString()
    {
        return "Text: " + getText();
    }

    @Override
    public boolean needsEmptySpan()
    {
        return false;
    }

    public boolean isStyle() {
        return style;
    }

    public void disableEmptySpanStyle() {
        this.style = false;
    }
}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.tools/src/com/openexchange/office/tools/htmldoc/Text.java <==
package com.openexchange.office.tools.htmldoc;

import org.apache.commons.lang3.StringEscapeUtils;

public class Text
        extends SubNode
{
    private static final String SPANBEFORE = "<span ";
    private static final String SPANMIDDLE = "style=\"font-family: Arial, Helvetica, sans-serif; font-weight: normal; font-style: normal; text-decoration: none; color: rgb(0, 0, 0); font-size: 11pt; line-height: 20px; background-color: transparent;\">";
    private static final String SPANEND    = "</span>";

    // ////////////////////////////////////////////////////

    private final String        text;
    private boolean style = true;

    public Text(
            String text, int position)
    {
        super(position, text.length());
        this.text = text;
    }

    public String getText()
    {
        return text;
    }

    @Override
    public boolean appendContent(
        StringBuilder document)
        throws Exception
    {
        document.append(SPANBEFORE);
        GenDocHelper.appendAttributes(getAttribute(), document);
        if (isStyle()) {
            document.append(SPANMIDDLE);
        } else {
            document.append(">");
        }

        document.append(StringEscapeUtils.escapeHtml4(text));
        document.append(SPANEND);
        return true;
    }

    @Override
    public String toString()
    {
        return "Text: " + getText();
    }

    @Override
    public boolean needsEmptySpan()
    {
        return false;
    }

    public boolean isStyle() {
        return style;
    }

    public void disableEmptySpanStyle() {
        this.style = false;
    }
}
